#
# __init__.py
#
# Created by Nguyen Quang Duy on Fri Dec 15 2023
#

import chromadb
from deepvision.config.config import DEEPVISION_DATABASER_DIR



class ChromaDbManager:
    _instance = None

    def __new__(cls):
        if cls._instance is None:
            cls._instance = super(ChromaDbManager, cls).__new__(cls)
            try:
                cls._instance.metric_type = "cosine"
                cls._instance.chromadb_manager = chromadb.PersistentClient(DEEPVISION_DATABASER_DIR)
            except Exception as e:
                raise TypeError(e)
        return cls._instance
    
    # def __init__(self):
    #     try:
    #         self.metric_type = "cosine"
    #         self.chromadb_manager = chromadb.PersistentClient(
    #             CHROMADB_SAVE_DIR)
    #     except Exception as e:
    #         raise TypeError(e)

    # def chromadb_init(self):
    #     try:
    #         return (chromadb.PersistentClient(CHROMADB_SAVE_DIR))
    #     except Exception as e:
    #         raise TypeError(e)

    def list_collections(self):
        return self.chromadb_manager.list_collections()

    def count_row_of_collection(self, collection_name):
        try:
            if self.check_collection_exists(collection_name):
                collection = self.chromadb_manager.get_collection(
                    collection_name)
                return collection.count()
            else:
                return 'Collection %s does not exists' % collection_name
        except Exception as e:
            raise TypeError(e)
        
    def check_collection_exists(self, collection_name):
        try:
            self.chromadb_manager.get_collection(collection_name)
            return True
        except Exception as e:
            return False
        
    def check_collection_exists_1(self, collection_name):
        try:
            listcls = self.chromadb_manager.list_collections()
            exists = any(collection.name == 'face_test_ip12' for collection in listcls)
            return exists
        except exists as e:
            raise TypeError(e)
        
    def load_collection(self, collection_name):
        try:
            if self.check_collection_exists(collection_name):
                collection = self.chromadb_manager.get_collection(
                    collection_name)
                return collection
            else:
                return 'Collection %s does not exists' % collection_name
        except Exception as e:
            raise TypeError(e)

    def drop_collection(self, collection_name):
        try:
            if self.check_collection_exists(collection_name):
                self.chromadb_manager.delete_collection(name=collection_name)
                return "Drop collection %s completed." % collection_name
            else:
                return 'Collection %s does not exists' % collection_name
        except Exception as e:
            raise TypeError(e)

    def create_collection(self, collection_name):
        collection = self.chromadb_manager.create_collection(
            name=collection_name, metadata={"hnsw:space": self.metric_type})
        return collection

    def load_or_create_collection(self, collection_name):
        collection = self.chromadb_manager.get_or_create_collection(
            name=collection_name, metadata={"hnsw:space": self.metric_type})
        return collection

    def rename_collection(self, collection, new_collection_name):
        collection.modify(name=new_collection_name)
    
    def remove_all_subject(self, collection_name):
        try:
            if self.check_collection_exists(collection_name):
                collection = self.chromadb_manager.get_collection(name=collection_name)
                search_results = collection.query(
                    query_embeddings=[1]*512,
                    n_results=51157,
                )
                for i in range(0, 51157, 40000):
                    collection.delete(
                        ids=search_results['ids'][0][i:i+40000]
                    )

                return "Delete all subject completed."
            else:
                return 'Collection %s does not exists' % collection_name
        except Exception as e:
            raise TypeError(e)
