#
# face_verification.py
#
# Created by Nguyen Quang Duy on Tue Dec 19 2023
#

import requests

from deepvision.common.multipart_constructor import multipart_constructor
from deepvision.common.typed_dict import ExpandedOptionsDict, check_fields_by_name
from deepvision.common import ClientRequest

class FaceVerificationClient(ClientRequest):
    """
        Compare face in image. It uses image path for encode and send to DeepVision 
        server with validation by image id.
    """

    def __init__(self, api_key: str, domain: str, port: str):
        super().__init__()
        self.api_key: str = api_key
        self.url: str = domain + ':' + port + self.client_url

    def get(self) -> dict:
        pass

    """
        POST request for compare face in image using image id. 
        
        :param image_path: Path to image in file system.
        :param image_id: subject id from previously added image.
        :param options: dictionary with options for server.
        
        :return: json from server.
    """

    def post(self,
             image: str = '' or bytes,
             face_id: str = '',
             options: ExpandedOptionsDict = {}) -> dict:
        url: str = self.url
        # Validation loop and adding fields to the url.
        cnt = 0
        for key in options.keys():
            # Checks fields with necessary rules.
            # key - key field by options.
            if cnt == 0:
                check_fields_by_name(key, options[key])
                url += '?' + key + "=" + str(options[key])
            else:
                check_fields_by_name(key, options[key])
                url += '&' + key + "=" + str(options[key])
        m = multipart_constructor(image)
        result = requests.post(url, data=m, headers={'Content-Type': m.content_type,
                                                     'x-api-key': self.api_key})
        return result.json()

    def put(self):
        pass

    def delete(self):
        pass