#
# face_verify.py
#
# Created by Nguyen Quang Duy on Tue Dec 19 2023
#

import requests

from deepvision.common.multipart_constructor import multipart_constructor_with_two_images
from deepvision.common.typed_dict import ExpandedOptionsDict, check_fields_by_name
from deepvision.common import ClientRequest
from .face_embedding import FaceEmbeddingClient


class FaceVerifyClient(ClientRequest):
    """
        Verify face in image with validation by image id.
    """

    def __init__(self, api_key: str, domain: str, port: str):
        super().__init__()
        self.face_embed: FaceEmbeddingClient = FaceEmbeddingClient(
            api_key=api_key,
            domain=domain,
            port=port
        )

    def verify(self,
               source_image: str = '' or bytes,
               target_image: str = '' or bytes,
               options: ExpandedOptionsDict = {}) -> dict:
        """
            POST request for verify face in image using source and target images. 

            :param source_image: Path to source image in file system.
            :param target_image: Path to target image in file system.
            :param image_id: face id from previously added image. 
            :param options: dictionary with options for server.

            :return: json.
        """
        pass
