#
# product_embedding.py
#
# Created by Nguyen Quang Duy on Mon Dec 18 2023
#

import requests

from deepvision.common.multipart_constructor import multipart_constructor, multipart_constructor_list_image
from deepvision.common.typed_dict import EmbedProbOptionsDict, check_fields_by_name
from deepvision.config.api_list import PRODUCT_EMBEDDING_IMAGE_API
from deepvision.common import ClientRequest

class ListProductEmbeddingClient(ClientRequest):
    """
        Embed list product in image.
    """

    def __init__(self, api_key: str, domain: str, port: str):
        super().__init__()
        self.client_url: str = PRODUCT_EMBEDDING_IMAGE_API
        self.api_key: str = api_key
        self.url: str = domain + ':' + port + self.client_url

    def get(self) -> dict:
        pass

    

    def post(self, image: str or bytes, options: EmbedProbOptionsDict = {}) -> dict:
        """
            POST request for embed list products in image. 
            
            :param image_path: Path to image in file system.
            :param options: dictionary with options for server.
            
            :return: json from server.
        """
        
        url: str = self.url 
        # Validation loop and adding fields to the url.
        cnt = 0
        for key in options.keys():
            # Checks fields with necessary rules.
            # key - key field by options.
            if cnt == 0:
                check_fields_by_name(key, options[key])
                url += '?' + key + "=" + str(options[key])
            else:
                check_fields_by_name(key, options[key])
                url += '&' + key + "=" + str(options[key])
            cnt+=1
        m = multipart_constructor(image)
        
        result = requests.post(url, data=m, headers={'Content-Type': m.content_type,
                                                     'x-api-key': self.api_key})
        return result.json()

    def put(self):
        pass

    def delete(self, subject: str = ''):
        pass