#
# water_meter_client.py
#
# Created by Nguyen Quang Duy on Tue Dec 19 2023
#

import requests

from deepvision.common.multipart_constructor import multipart_constructor
from deepvision.common.typed_dict import DetProbOptionsDict, check_fields_by_name
from deepvision.config.api_list import FACE_DETECTOR_API
from deepvision.common import ClientRequest

class WaterMeterClient(ClientRequest):
    def __init__(self, api_key: str, domain: str, port: str):
        super().__init__()
        self.client_url: str = FACE_DETECTOR_API
        self.api_key: str = api_key
        self.url: str = domain + ':' + port + self.client_url

    def get(self) -> dict:
        pass

    """
        POST request for detect faces in image. 
        
        :param image_path: Path to image in file system.
        :param options: dictionary with options for server.
        
        :return: json from server.
    """

    def post(self, image: str = '' or bytes, options: DetProbOptionsDict = {}) -> dict:
        url: str = self.url 
        cnt = 0
        for key in options.keys():
            # Checks fields with necessary rules.
            # key - key field by options.
            if cnt == 0:
                check_fields_by_name(key, options[key])
                url += '?' + key + "=" + str(options[key])
            else:
                check_fields_by_name(key, options[key])
                url += '&' + key + "=" + str(options[key])
        m = multipart_constructor(image)
        result = requests.post(url, data=m, headers={'Content-Type': m.content_type,
                                                     'x-api-key': self.api_key})
        return result.json()

    def put(self):
        pass

    def delete(self, subject: str = ''):
        pass