#
# face_detection_service.py
#
# Created by Nguyen Quang Duy on Sat Dec 16 2023
#

import os
import requests
import numpy as np
import pandas as pd
import pyarrow as pa
from typing import List
from deepvision.common import Service
from deepvision.common.typed_dict import AllOptionsDict
from deepvision.common.typed_dict import AllOptionsDict, ExpandedOptionsDict, pass_dict
from deepvision.use_cases.face.detect_face_from_image import DetectFaceFromImage


class FaceDetectionService(Service):

    def __init__(self, api_key: str, domain: str, port: str, options: AllOptionsDict = {}):
        """Init service"""
        super().__init__(api_key, options)
        self.available_services = []
        self.detect_face_from_image: DetectFaceFromImage = DetectFaceFromImage(
            domain=domain,
            port=port,
            api_key=api_key
        )

    def get_available_functions(self) -> List[str]:
        """
        Get List of available functions in service
        :return:
        """
        return self.available_services

    def detect(self, image_path: str, options: ExpandedOptionsDict = {}) -> dict:
        """
        Detect face in image
        :param image_path:
        :param options:
        :return:
        """
        request = DetectFaceFromImage.Request(
            api_key=self.api_key,
            image_path=image_path
        )
        return self.detect_face_from_image.execute(request, pass_dict(
            self.options, ExpandedOptionsDict) if options == {} else options)