#
# face_recognition_service.py
#
# Created by Nguyen Quang Duy on Sat Dec 16 2023
#

import os
import requests
import numpy as np
import pandas as pd
import pyarrow as pa
from typing import List
from deepvision.common import Service
from deepvision.common.typed_dict import AllOptionsDict
from deepvision.collections import FaceCollection, Subjects
from deepvision.use_cases.face.recognize_face_from_image import RecognizeFaceFromImage


class FaceRecognitionService(Service):

    def __init__(self, api_key: str, domain: str, port: str, options: AllOptionsDict = {}):
        """Init service"""
        super().__init__(api_key, options)
        self.available_services = []
        self.recognize_face_from_images: RecognizeFaceFromImage = RecognizeFaceFromImage(
            domain=domain,
            port=port,
            api_key=api_key
        )
        self.face_collection: FaceCollection = FaceCollection(
            domain=domain,
            port=port,
            api_key=api_key,
            options=options
        )
        self.subjects: Subjects = Subjects(
            domain=domain,
            port=port,
            api_key=api_key,
            options=options
        )

    def get_available_functions(self) -> List[str]:
        """
        Get List of available functions in service
        :return:
        """
        return self.available_services

    def get_face_collection(self) -> FaceCollection:
        """
        Get face collection
        :return:
        """
        return self.face_collection

    def get_subjects(self) -> Subjects:
        """
        Get subjects
        :return:
        """
        return self.subjects

    def recognize(self, image_path: str, options: AllOptionsDict = {}) -> dict:
        """
        Recognize face in image
        :param image_path:
        :param options:
        :return:
        """
        request = RecognizeFaceFromImage.Request(
            api_key=self.api_key,
            image_path=image_path
        )
        return self.recognize_face_from_images.execute(request, self.options if options == {} else options)