#
# face_verification_service.py
#
# Created by Nguyen Quang Duy on Sat Dec 16 2023
#

from deepvision.use_cases.face.verifiy_face_from_images import VerifyFaceFromImage
from deepvision.common.typed_dict import AllOptionsDict, ExpandedOptionsDict, pass_dict
from typing import List

from deepvision.common import Service


class FaceVerifyService(Service):
    """Verification service"""

    def __init__(self, api_key: str, domain: str, port: str, options: AllOptionsDict = {}):
        """Init service with define API Key"""
        super().__init__(api_key, options)
        self.available_services = []
        self.verify_face_from_image: VerifyFaceFromImage = VerifyFaceFromImage(
            domain=domain,
            port=port,
            api_key=api_key
        )

    def get_available_functions(self) -> List[str]:
        """
        Get List of available functions in service
        :return:
        """
        return self.available_services

    def verify(self, source_image_path: str, target_image_path: str, options: ExpandedOptionsDict = {}) -> dict:
        """
        Verify face in images
        :param source_image_path:
        :param target_image_path:
        :param options:
        :return:
        """
        request = VerifyFaceFromImage.Request(api_key=self.api_key,
                                              source_image_path=source_image_path,
                                              target_image_path=target_image_path)
        return self.verify_face_from_image.execute(request,
            options=pass_dict(
                self.options, ExpandedOptionsDict) if options == {} else options
        )
