#
# ocr_service.py
#
# Created by Nguyen Quang Duy on Tue Dec 19 2023
#

from typing import List
from deepvision.common import Service
from deepvision.common.typed_dict import AllOptionsDict
from deepvision.common.typed_dict import AllOptionsDict, ExpandedOptionsDict, pass_dict
from deepvision.use_cases.ocr_image import OCRImage


class OCRService(Service):

    def __init__(self, api_key: str, domain: str, port: str, options: AllOptionsDict = {}):
        """Init service"""
        super().__init__(api_key, options)
        self.available_services = []
        self.ocr_image: OCRImage = OCRImage(
            domain=domain,
            port=port,
            api_key=api_key
        )

    def get_available_functions(self) -> List[str]:
        """
        Get List of available functions in service
        :return:
        """
        return self.available_services

    def extract(self, image_path: str, options: ExpandedOptionsDict = {}) -> dict:
        """
        OCR
        :param image_path:
        :param options:
        :return:
        """
        request = OCRImage.Request(
            api_key=self.api_key,
            image_path=image_path
        )
        return self.ocr_image.execute(request, pass_dict(
            self.options, ExpandedOptionsDict) if options == {} else options)