#
# product_recognition_service.py
#
# Created by Nguyen Quang Duy on Sat Dec 16 2023
#

from typing import List
from deepvision.common import Service
from deepvision.common.typed_dict import AllOptionsDict
from deepvision.collections import ProductCollection, Products
from deepvision.use_cases.product.recognize_product_from_image import RecognizeProductFromImage


class ProductRecognitionService(Service):
    """Recognition service"""
    
    def __init__(self, api_key: str, domain: str, port: str, options: AllOptionsDict = {}):
        """Init service"""
        super().__init__(api_key, options)
        self.available_services = []
        self.recognize_product_from_images: RecognizeProductFromImage = RecognizeProductFromImage(
            domain=domain,
            port=port,
            api_key=api_key
        )
        self.product_collection: ProductCollection = ProductCollection(
            domain=domain,
            port=port,
            api_key=api_key,
            options=options
        )
        self.products: Products = Products(
            domain=domain,
            port=port,
            api_key=api_key,
            options=options
        )

    def get_available_functions(self) -> List[str]:
        """
        Get List of available functions in service
        :return:
        """
        return self.available_services

    def get_product_collection(self) -> ProductCollection:
        """
        Get product collection
        :return:
        """
        return self.product_collection

    def get_products(self) -> Products:
        """
        Get products
        :return:
        """
        return self.products

    def recognize(self, collection_name: str, image_path: str, options: AllOptionsDict = {}) -> dict:
        """
        Recognize product in image
        :param collection_name:
        :param image_path:
        :param options:
        :return:
        """
        request = RecognizeProductFromImage.Request(
            collection_name=collection_name,
            api_key=self.api_key,
            image_path=image_path
        )
        return self.recognize_product_from_images.execute(request, self.options if options == {} else options)